@@ -262,13 +262,15 @@ class Object(object):
 
     .. attribute:: image_fps
 
-       The animation rate in frames per second.  If set to
-       :const:`None`, the value recommended by the sprite is used.
+       The animation rate in frames per second.  Can be negative, in
+       which case animation will be reversed.  If set to :const:`None`,
+       the value recommended by the sprite is used.
 
     .. attribute:: image_speed
 
-       The animation rate as a factor of :attr:`sge.game.fps`.  If set
-       to :const:`None`, the value recommended by the sprite is used.
+       The animation rate as a factor of :attr:`sge.game.fps`.  Can be
+       negative, in which case animation will be reversed.  If set to
+       :const:`None`, the value recommended by the sprite is used.
 
     .. attribute:: image_xscale
 
@@ -592,14 +594,16 @@ class Object(object):
         if value is None:
             value = self.sprite.fps if self.sprite is not None else 0
 
-        self.__fps = abs(value)
-        if self.__fps != 0:
-            self.rd["frame_time"] = 1000 / self.__fps
+        self.__fps = value
+        if value:
+            self.rd["frame_time"] = 1000 / value
             if not self.rd["frame_time"]:
                 # This would be caused by a round-off to 0 resulting
                 # from a much too high frame rate.  It would cause a
                 # division by 0 later, so this is meant to prevent that.
                 self.rd["frame_time"] = 0.000001
+                w = "Could not calculate timing for {:.2e} FPS.".format(value)
+                warnings.warn(w)
         else:
             self.rd["frame_time"] = None
 
