@@ -165,9 +165,7 @@ class Room(object):
         """
         obj.alive = True
         if obj not in self.objects:
-            objects = self.objects[:]
-            objects.append(obj)
-            self.objects = objects
+            self.objects.append(obj)
 
             if self is sge.game.current_room and self.rd["started"]:
                 obj.event_create()
@@ -184,10 +182,8 @@ class Room(object):
 
         - ``obj`` -- The :class:`sge.Object` object to remove.
         """
-        objects = self.objects[:]
-        while obj in objects:
-            objects.remove(obj)
-        self.objects = objects
+        while obj in self.objects:
+            self.objects.remove(obj)
 
         while obj in self.__new_objects:
             self.__new_objects.remove(obj)
@@ -196,7 +192,8 @@ class Room(object):
         if self is sge.game.current_room:
             obj.event_destroy()
 
-    def start(self, transition=None, transition_time=1500):
+    def start(self, transition=None, transition_time=1500,
+              transition_arg=None):
         """
         Start the room.
 
@@ -226,6 +223,18 @@ class Room(object):
         - ``transition_time`` -- The time the transition should take in
           milliseconds.  Has no effect if ``transition`` is
           :const:`None`.
+
+        - ``transition_arg`` -- An arbitrary argument that can be used
+          by the following transitions:
+
+          - ``"wipe_matrix"`` -- The size of each square in the matrix
+            transition as a tuple in the form ``(w, h)``, where ``w`` is
+            the width and ``h`` is the height.  Default is ``(4, 4)``.
+          - ``"iris_in"`` and ``"iris_out"`` -- The position of the
+            center of the iris as a tuple in the form ``(x, y)``, where
+            ``x`` is the horizontal location relative to the window and
+            ``y`` is the vertical location relative to the window.
+            Default is the center of the window.
         """
         transitions = {
             "fade": r_update_fade, "dissolve": r_update_dissolve,
@@ -243,6 +252,7 @@ class Room(object):
             self.rd["t_update"] = transitions[transition]
             self.rd["t_sprite"] = sge.Sprite.from_screenshot()
             self.rd["t_duration"] = transition_time
+            self.rd["t_arg"] = transition_arg
             self.rd["t_time_passed"] = 0
             self.rd["t_complete_last"] = 0
             self.rd["t_matrix_remaining"] = None
@@ -269,8 +279,11 @@ class Room(object):
             self.event_room_resume()
 
         while self.__new_objects:
-            self.__new_objects[0].event_create()
-            del self.__new_objects[0]
+            self.__new_objects.pop(0).event_create()
+
+        # Prevent sudden movements from happening at the start of a room
+        # due to delta timing, and make sure transitions happen fully.
+        r.game_clock.tick()
 
     def project_dot(self, x, y, z, color):
         """
