@@ -37,9 +37,6 @@ import six
 import sge
 
 
-# How large the squares that make up the matrix transition are.
-MATRIX_PSIZE = 4
-
 # How often to call cache.prune in milliseconds.
 CACHE_PRUNE_TIME = 8000
 
@@ -448,14 +445,17 @@ def bl_update(self, time_passed):
                 # This would be caused by a round-off to 0 resulting
                 # from a much too high frame rate.  It would cause a
                 # division by 0 later, so this is meant to prevent that.
-                self.rd["frame_time"] = 0.01
+                self.rd["frame_time"] = 0.0000001
+                w = "Could not calculate timing for {:.2e} FPS.".format(
+                    self.sprite.fps)
+                warnings.warn(w)
         else:
             self.rd["frame_time"] = None
 
     if self.rd["frame_time"] is not None:
         self.rd["count"] += time_passed
-        self.rd["image_index"] += int(self.rd["count"] // self.rd["frame_time"])
-        self.rd["count"] %= self.rd["frame_time"]
+        self.rd["image_index"] += int(self.rd["count"] / self.rd["frame_time"])
+        self.rd["count"] %= abs(self.rd["frame_time"])
         self.rd["image_index"] %= self.sprite.frames
 
 
@@ -493,8 +493,8 @@ def o_update(self, time_passed, delta_mult):
     # Update the animation frame.
     if self.image_fps:
         self.rd["anim_count"] += time_passed
-        self.image_index += int(self.rd["anim_count"] // self.rd["frame_time"])
-        self.rd["anim_count"] %= self.rd["frame_time"]
+        self.image_index += int(self.rd["anim_count"] / self.rd["frame_time"])
+        self.rd["anim_count"] %= abs(self.rd["frame_time"])
 
     # Alarms
     activated_alarms = []
@@ -720,7 +720,7 @@ def r_update_dissolve(self, complete):
     h = transition_sprite.height
     diff = complete - self.rd["t_complete_last"]
     c = sge.Color((0, 0, 0, int(round(diff * 255))))
-    eraser = sge.Sprite(width=w, height=w)
+    eraser = sge.Sprite(width=w, height=h)
     eraser.draw_rectangle(0, 0, w, h, c)
     transition_sprite.draw_sprite(eraser, 0, 0, 0,
                                   blend_mode=sge.BLEND_RGBA_SUBTRACT)
@@ -744,7 +744,7 @@ def r_update_pixelate(self, complete):
     else:
         diff = (complete - self.rd["t_complete_last"]) * 5
         c = sge.Color((0, 0, 0, int(round(diff * 255))))
-        eraser = sge.Sprite(width=w, height=w)
+        eraser = sge.Sprite(width=w, height=h)
         eraser.draw_rectangle(0, 0, w, h, c)
         transition_sprite.draw_sprite(eraser, 0, 0, 0,
                                       blend_mode=sge.BLEND_RGBA_SUBTRACT)
@@ -836,10 +836,18 @@ def r_update_wipe_downright(self, complete):
 
 def r_update_wipe_matrix(self, complete):
     transition_sprite = self.rd["t_sprite"]
+
+    if self.rd["t_arg"]:
+        pw, ph = self.rd["t_arg"]
+    else:
+        pw = 4
+        ph = 4
+
     w = transition_sprite.width
     h = transition_sprite.height
-    mw = int(w / MATRIX_PSIZE)
-    mh = int(h / MATRIX_PSIZE)
+    mw = int(w / pw)
+    mh = int(h / ph)
+
     remaining = self.rd["t_matrix_remaining"]
     if remaining is None:
         remaining = []
@@ -853,8 +861,7 @@ def r_update_wipe_matrix(self, complete):
     while new_erase > 0 and remaining:
         new_erase -= 1
         x, y = remaining.pop(random.randrange(len(remaining)))
-        transition_sprite.draw_erase(x * MATRIX_PSIZE, y * MATRIX_PSIZE,
-                                     MATRIX_PSIZE, MATRIX_PSIZE)
+        transition_sprite.draw_erase(x * pw, y * ph, pw, ph)
     transition_sprite.draw_unlock()
     self.rd["t_matrix_remaining"] = remaining
 
@@ -863,9 +870,15 @@ def r_update_iris_in(self, complete):
     transition_sprite = self.rd["t_sprite"]
     w = transition_sprite.width
     h = transition_sprite.height
-    x = w / 2
-    y = h / 2
-    r = int(math.hypot(x, y) * (1 - complete))
+
+    if self.rd["t_arg"]:
+        x, y = self.rd["t_arg"]
+    else:
+        x = w / 2
+        y = h / 2
+
+    r = int(math.hypot(max(x, self.width - x), max(y, self.height - y)) *
+            (1 - complete))
     eraser = sge.Sprite(width=w, height=h)
     eraser_eraser = sge.Sprite(width=w, height=h)
     eraser_eraser.draw_circle(x, y, r, fill=sge.Color((0, 0, 0, 255)))
@@ -884,9 +897,15 @@ def r_update_iris_out(self, complete):
     transition_sprite = self.rd["t_sprite"]
     w = transition_sprite.width
     h = transition_sprite.height
-    x = w / 2
-    y = h / 2
-    r = int(math.hypot(x, y) * complete)
+
+    if self.rd["t_arg"]:
+        x, y = self.rd["t_arg"]
+    else:
+        x = w / 2
+        y = h / 2
+
+    r = int(math.hypot(max(x, self.width - x), max(y, self.height - y)) *
+            (1 - complete))
     eraser = sge.Sprite(width=w, height=h)
     eraser.draw_circle(x, y, r, fill=sge.Color((0, 0, 0, 255)))
     transition_sprite.draw_sprite(eraser, 0, 0, 0,
